window.Gleam.initSearch([{"doc":"lenient_parse","title":"lenient_parse","content":"# lenient_parse\n\n[![Package Version](https://img.shields.io/hexpm/v/lenient_parse)](https://hex.pm/packages/lenient_parse)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lenient_parse/)\n\n```sh\ngleam add lenient_parse\n```\n```gleam\nimport lenient_parse\nimport gleam/float\nimport gleam/io\n\npub fn main() {\n  &quot;1&quot; |&gt; float.parse |&gt; io.debug\n  // Error(Nil)\n\n  &quot;1&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(1.0)\n}\n```\n","url":"index.html"},{"doc":"lenient_parse","title":"to_float","content":"pub fn to_float(text: String) -&gt; Result(Float, Nil)\n Converts a string to a float using a more lenient parsing method than gleam&#39;s `float.parse()`. It behaves similarly to Python&#39;s `float()` built-in function.\n\n ## Examples\n\n \n lenient_parse.to_float(&quot;1.001&quot;)    // -&gt; Ok(1.001)\n lenient_parse.to_float(&quot;1&quot;)        // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1.&quot;)       // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1.0&quot;)      // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;.1&quot;)       // -&gt; Ok(0.1)\n lenient_parse.to_float(&quot;0.1&quot;)      // -&gt; Ok(0.1)\n lenient_parse.to_float(&quot;+123.321&quot;) // -&gt; Ok(123.321)\n lenient_parse.to_float(&quot;-123.321&quot;) // -&gt; Ok(-123.321)\n lenient_parse.to_float(&quot; 1.0 &quot;)    // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1_000.0&quot;)  // -&gt; Ok(1000.0)\n lenient_parse.to_float(&quot; &quot;)        // -&gt; Error(Nil)\n lenient_parse.to_float(&quot;&quot;)         // -&gt; Error(Nil)\n lenient_parse.to_float(&quot;abc&quot;)      // -&gt; Error(Nil)\n \nSynonyms:\nlenient_parse.to_float\nlenient_parse to_float","url":"lenient_parse.html#to_float"},{"doc":"lenient_parse","title":"to_int","content":"pub fn to_int(text: String) -&gt; Result(Int, Nil)\n Converts a string to an integer using a more lenient parsing method than gleam&#39;s `int.parse()`.\n It behaves similarly to Python&#39;s `int()` built-in function.\n\n ## Examples\n\n \n lenient_parse.to_int(&quot;123&quot;)   // -&gt; Ok(123)\n lenient_parse.to_int(&quot;+123&quot;)  // -&gt; Ok(123)\n lenient_parse.to_int(&quot;-123&quot;)  // -&gt; Ok(-123)\n lenient_parse.to_int(&quot;0123&quot;)  // -&gt; Ok(123)\n lenient_parse.to_int(&quot; 123 &quot;) // -&gt; Ok(123)\n lenient_parse.to_int(&quot;1_000&quot;) // -&gt; Ok(1000)\n lenient_parse.to_int(&quot;&quot;)      // -&gt; Error(Nil)\n lenient_parse.to_int(&quot;1.0&quot;)   // -&gt; Error(Nil)\n lenient_parse.to_int(&quot;abc&quot;)   // -&gt; Error(Nil)\n \nSynonyms:\nlenient_parse.to_int\nlenient_parse to_int","url":"lenient_parse.html#to_int"},{"doc":"lenient_parse","title":"lenient_parse","content":"","url":"lenient_parse.html"}]);